@@ -341,7 +341,7 @@ public:
 
   KPopupMenu* accountContextMenu(void) const { return m_accountMenu; };
 
-  KMyMoneyViewBase* addPage(const QString& title, const QPixmap& pixmap = QPixmap());
+  KMyMoneyViewBase* addPage(const QString& title, const QString& icon = QString());
 
   void addWidget(QWidget* w);
 
